diff lisp/calendar/appt.el @ 777:c99faf9381bb

*** empty log message ***
author Jim Blandy <jimb@redhat.com>
date Wed, 15 Jul 1992 00:32:19 +0000
parents 8a533acedb77
children 4f28bd14272c
line wrap: on
line diff
--- a/lisp/calendar/appt.el	Tue Jul 14 23:23:55 1992 +0000
+++ b/lisp/calendar/appt.el	Wed Jul 15 00:32:19 1992 +0000
@@ -291,7 +291,7 @@
     ;; Make sure we're not in the minibuffer
     ;; before splitting the window.
 
-    (if (= (screen-height)
+    (if (= (frame-height)
            (nth 3 (window-edges (selected-window))))
         nil
       (appt-select-lowest-window)
@@ -313,7 +313,7 @@
           (beep 1))
       (kill-buffer appt-disp-buf))))
 
 ;; Select the lowest window on the screen.
 (defun appt-select-lowest-window ()
   (setq lowest-window (selected-window))
   (let* ((bottom-edge (car (cdr (cdr (cdr (window-edges))))))
@@ -313,7 +313,7 @@
       (kill-buffer appt-disp-buf))))
 
-;; Select the lowest window on the screen.
+;; Select the lowest window on the frame.
 (defun appt-select-lowest-window ()
   (setq lowest-window (selected-window))